@@ -61,11 +61,11 @@ def E(expr,color = "red"):
       #Es decir, si es un simbolo sin valor (None) o coleccion de simbolos. Entonces:
       DataRealSymbolList.append([element[0],element[0]])
   #display(DataRealSymbolList)
-  D(expr)
+  
 
   if isinstance(expr,sy.core.relational.Equality):
     D(expr.subs(DataRealSymbolList))
-    D(expr.subs(DatosList))
+    D(sy.N(expr.subs(DatosList)))
   
   if isinstance(expr,list):
     D([expr[0],expr[1].subs(DataRealSymbolList)])
